==> nextcloud-20.0.12.tgz: nextcloud/apps/weather_status/l10n/zh_HK.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "地址不詳",
    "No result." : "無結果",
    "Malformed JSON data." : "JSON 資料格式錯誤。",
    "Error" : "錯誤",
    "Weather status" : "天氣報告",
    "Weather status in your dashboard" : "您儀表板中的天氣報告",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "整合在儀表板應用程式中的天氣報告。\n    用戶的位置可以自動偵測或手動定義。然後會顯示6小時的預測。\n    此狀態也可以整合到其他地方，如「日曆」應用程式。",
    "Detect location" : "偵測位置",
    "Set custom address" : "設定自訂位置",
    "Favorites" : "我的最愛",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} 晴朗於 {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} 多雲於 {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} 白天晴朗於 {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} 夜晚晴朗於 {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} 局部多雲於 {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} 有霧於 {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} 小雨於 {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} 下雨於 {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} 大雨於 {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} 陣雨於 {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} 小陣雨於 {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} 大陣雨於 {time}",
    "More weather for {adr}" : "{adr} 的更多天氣",
    "Loading weather" : "正在載入天氣",
    "Set location for weather" : "設定天氣位置",
    "Remove from favorites" : "從最愛中移除",
    "Add as favorite" : "加到我的最愛",
    "You are not logged in." : "您未登入",
    "There was an error getting the weather status information." : "取得天氣報告資訊時發生錯誤。",
    "No weather information found" : "找不到天氣資訊",
    "Location not found" : "找不到位置",
    "There was an error setting the location address." : "設定位置地址時發生錯誤。",
    "There was an error setting the location." : "設定位置時發生錯誤。",
    "There was an error saving the mode." : "儲存模式時發生錯誤。",
    "There was an error using personal address." : "使用個人地址時發生錯誤。",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "整合在儀表板應用程式中的天氣報告。\n    用戶的位置可以自動偵測或手動定義。然後會顯示6小時的預測。\n    此狀態也可以整合到其他地方，如「日曆」應用程式。"
},
"nplurals=1; plural=0;");

==> nextcloud-21.0.0p0.tgz: nextcloud/apps/weather_status/l10n/zh_HK.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "地址不詳",
    "No result." : "無結果",
    "Malformed JSON data." : "JSON 資料格式錯誤。",
    "Error" : "錯誤",
    "Weather status" : "天氣報告",
    "Weather status in your dashboard" : "您儀表板中的天氣報告",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "整合在儀表板應用程式中的天氣報告。\n    使用者的位置可以自動偵測或手動定義。然後會顯示6小時的預測。\n    此狀態也可以整合到其他地方，如「日曆」應用程式。",
    "Detect location" : "偵測位置",
    "Set custom address" : "設定自訂位置",
    "Favorites" : "我的最愛",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} 晴朗於 {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} 多雲於 {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} 白天晴朗於 {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} 夜晚晴朗於 {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} 局部多雲於 {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} 有霧於 {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} 小雨於 {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} 下雨於 {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} 大雨於 {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} 陣雨於 {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} 小陣雨於 {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} 大陣雨於 {time}",
    "More weather for {adr}" : "{adr} 的更多天氣",
    "Loading weather" : "正在載入天氣",
    "Set location for weather" : "設定天氣位置",
    "Remove from favorites" : "從最愛中移除",
    "Add as favorite" : "新增為最愛",
    "You are not logged in." : "您未登入",
    "There was an error getting the weather status information." : "取得天氣報告資訊時發生錯誤。",
    "No weather information found" : "找不到天氣資訊",
    "Location not found" : "找不到位置",
    "There was an error setting the location address." : "設定位置地址時發生錯誤。",
    "There was an error setting the location." : "設定位置時發生錯誤。",
    "There was an error saving the mode." : "儲存模式時發生錯誤。",
    "There was an error using personal address." : "使用個人地址時發生錯誤。",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "整合在儀表板應用程式中的天氣報告。\n    使用者的位置可以自動偵測或手動定義。然後會顯示6小時的預測。\n    此狀態也可以整合到其他地方，如「日曆」應用程式。"
},
"nplurals=1; plural=0;");
